clear
set mem 100m
set more off



/* Read in Work Data */
use "Data/work_data.dta"
append using "Data/money_data.dta", generate(moneychoices)
append using "Data/commit_data.dta", generate(commitchoices)
sort id
merge m:1 id using "Data/trial_data.dta"

/* Which choice environment */
gen choices = 1
replace choices = 2 if moneychoices == 1
replace choices = 3 if commitchoices ==1

egen totalworkchoices = total(choices ==1), by(id)
egen totalmoneychoices = total(moneychoices), by(id)
egen totalcommitchoices = total(commitchoices), by(id)
gen totalchoices = totalworkchoices + totalmoneychoices + totalcommitchoices

capture labe drop choicelab
label define choicelab 1 "Task Choices" 2 "Monetary Discounting" 3 "Commitment Decisions"
label values choices choicelab

/* Label Round */
capture label drop roundlab
label define roundlab 1 "Week 1 Allocations" 2 "Week 2 Allocations" 4 "Week 4 Allocations" 5 "Week 5 Allocations"
label values round roundlab

capture label drop tasklab
label define tasklab 1 "Greek Transcription" 2 "Tetris"
label values task tasklab

capture drop late
gen late = (round > 2)
replace late = . if choices != 1
label define latelab 0 "Weeks 1 and 2" 1 "Weeks 4 and 5"
label values late latelab


/* Identify Missing Data */
gen misswork =0 
replace misswork = 1 if  (date1_work == 0 & date2_work== 0)

egen totalmisswork = total(misswork), by(id)

gen missmoney = 0
replace missmoney = 1 if (money1 == -1 & money2== -1)

egen totalmissmoney = total(missmoney), by(id)


/**** Data Cleaning */
/* Clean Up Bad Data */
replace date1_work = . if  (date1_work == 0 & date2_work ==0)
replace date2_work = . if  (date1_work == . & date2_work== 0)
replace money1 = . if (money1 == -1 & money2== -1)
replace money2 = . if (money1 == . & money2== -1)


/* Identify Data with No Variance within a Set of Choices*/
capture drop temp
egen temp = sd(date1_work) if choices ==1, by(task round id)
capture drop temp2
gen temp2 = (temp == 0)
replace temp2 = . if choices != 1
capture drop sdwork0
egen sdwork0 = mean(temp2), by(id)

capture drop temp
egen temp = sd(date2_work) if choices ==1, by(task round id)
capture drop temp2
gen temp2 = (temp == 0)
replace temp2 = . if choices != 1
capture drop sdwork02
egen sdwork02 = mean(temp2), by(id)


/* Identify observation count */
bysort id choices: gen count = _N
bysort id: gen obscount = _n

/* Identify non-attrited sample */
capture drop temp
egen temp = group(id) if count == 40 
capture drop uniqid
egen uniqid = mean(temp), by(id)


/*** Attention: Dropping Subjects here ****/
/* Select Out Bizarre Choices (full weeks with no variation) and Missed Data Set */
/* Subject u25/i87: No variation in Weeks 4 or 5 (10 allocations of 50,0 in both weeks)*/
/* Subject u32/i101: No variation in Week 2 (10 allocations of 0, X), 1st block Estimate of beta = 0.25 */
/* Subject u36/i109: No variation in Week 5 (10 allocations of 50,0) */
/* Subject u47/i139: No variation in Week 5, Or Week 4 (effectively) (10 allocations of 20,X)  */
/* Subject u49/i145: No variation in Week 5 (10 allocations of 50,0) */
/* Subject u50/i147: No variation in Week 1  (10 allocations of 50,0) 1st block Estimate of beta = 0.6  */
/* Subject u70/i249: No variation in Week 2  (10 allocations of 0, X) 1st block estimate of beta = 0.24 */
/* Subject u73/i255: No variation in Weeks 2, 4, 5 (20 allocations of 0, X)  (10 allocations of 50,0) 1st block estimate of beta = 0.43*/
/* Subject u83/i279: No vatiation in Weeks 2 or 5 (20 allocations of 0, X) 1st block estimate of beta = 2.629*/
/* Subject u87/i289: No variation in Week 2 or 5 for tetris (reinstate) */
/* Subject u67/i243: Computer glitch, missing data */

replace uniqid = . if sdwork0 >= 0.25
replace uniqid = . if sdwork02 >= 0.25
replace uniqid = . if  id == 243
replace uniqid = 87 if id == 289

/* Who Was Dropped For Having Insufficient Variation */
capture drop temp
gen temp = 0 if uniqid != .
replace temp = 1 if count == 40 & uniqid == .
replace temp = . if id ==243

capture drop dropped
egen dropped = mean(temp), by(id)


/* Identify Attrited Sample */
capture drop attrit
gen attrit = 0
replace attrit = 1 if uniqid == .

/* Identify Leavers */
capture drop leaver
gen leaver = 0
replace leaver = 1 if attrit == 1 & dropped == .
replace leaver = 0 if id == 243

/* Identify Expiration Date on Allocations */
capture drop expiretime
gen expiretime = 24 - hh(decisiontime) - (mm(decisiontime)/60)
replace expiretime = . if round  != 2
replace expiretime = . if choices != 1

capture drop minexpiretime
egen minexpiretime = min(expiretime), by(uniqid )
replace minexpiretime = . if uniqid == .

capture drop medianexpiretime
egen medianexpiretime = cut(minexpiretime) if uniqid != ., group(2)

/* Identify Those that Migh Be Exhausted*/
/* Based on Trial Time */
capture drop mediantrialtime
egen mediantrialtime = cut(trialtimetotal) if uniqid != ., group(2)

/* Based on Not Completing with Flying Colors */
capture drop medianlev
egen medianlev = cut(levdistancetotal) if uniqid != ., group(2)


/* Generate Price Ratio and Other Relevant Variables for Work Decisions */
/* Price Ratio*/
gen pratio = 1/discountrate
capture drop logpratio
gen logpratio = log(1/discountrate)

/* Cost Ratio */
capture dop logworkratio
gen logworkratio = log((date1_work+10)/(date2_work+10))

/* Delay Length */
capture drop k
gen k = 7

/* Censored Observation: Corner Solution */
capture drop cnsrd
gen cnsrd = 0
replace cnsrd = -1 if date1_work == 0
replace cnsrd = 1 if date1_work == 50

/* Interval Limits on Cost Ratio */
gen logworkratiolow = logworkratio
replace logworkratiolow = . if  cnsrd == -1
gen logworkratiohigh = logworkratio
replace logworkratiohigh = . if cnsrd == 1

/* Interior Solution */
capture drop interior
gen interior = (cnsrd ==0)
replace interior = . if choices != 1

capture drop totinterior
egen totinterior = total(interior), by(id)


/* Non-monotonicities in Demand for Work */
capture drop nmwork
by id  (round task discountrate), sort: gen nmwork = (date1_work[_n]  - date1_work[_n-1]) if  date1_work != .
replace nmwork = . if choices != 1
replace nmwork = . if discountrate == 0.5

capture drop nmworkdum
gen nmworkdum = (nmwork > 0)
replace nmworkdum = . if nmwork == .

capture drop nmworkdist
gen nmworkdist = nmworkdum*nmwork
replace nmworkdist = . if nmwork == .

capture drop totnmworkdum
egen totnmworkdum = total(nmworkdum), by(id)

capture drop meannmworkdist
egen meannmworkdist = mean(nmworkdist), by(id)

/* Key Variables By Round and Task */
gen logpratio1=logpratio*(round==1)
gen logpratio2=logpratio*(round==2)
gen logpratio4=logpratio*(round==4)
gen logpratio5=logpratio*(round==5)
gen k1 = k*(round==1)
gen k2 = k*(round==2)
gen k4 = k*(round==4)
gen k5 = k*(round==5)
gen t0 = (round ==2 | round ==5)

gen logpratiotask2 = logpratio*(task==2)
gen ktask2 = k*(task ==2)
gen t0task2 = t0*(task==2)





/* Generate Relevant Variables for Monetary Decisions */
capture drop decisionblock 
gen decisionblock = 2
replace decisionblock = 1 if date_2 == 19052 | date_2 == 19053 | date_2 == 19054
replace decisionblock = 3 if date_1 == 19052 | date_1 == 19053 | date_1 == 19054
replace decisionblock = 4 if round ==4
replace decisionblock = . if moneychoices == 0 | moneychoices == .

/* Define Monetary Discounting Sample */
/* Subject 8: Missing 5/20 decisions */
/* Subject 9: Missing 10/20 decisions */
/* Subject 26: Missing 5/20 decisions */
/* Subject 68: Missing 5/20 deicsions */
/* Subject 84: Missing 15/20 decisions */
capture drop moneysample
gen moneysample = 1
replace moneysample = 0 if attrit == 1
replace moneysample = 0 if totalmissmoney  != 0

capture drop moneysample2
gen moneysample2 = 1
replace moneysample2 = 0 if attrit == 1
replace moneysample2 = 1 if dropped == 1
replace moneysample2 = 0 if totalmissmoney  != 0


/* Monetary Delay Length */
capture drop moneyk
gen moneyk = 21
replace moneyk = 42 if decisionblock == 2
replace moneyk = . if moneychoices == 0 | moneychoices == .

/* Monetary t==0*/
capture drop moneyt0
gen moneyt0 = 0
replace moneyt0 = 1 if decisionblock == 1 | decisionblock == 2 | decisionblock == 4
replace moneyt0 = . if moneychoices == 0 | moneychoices == .

capture label drop klab
label define klab 21 "3 Week Delay" 42 "6 Week Delay"
label values moneyk klab

/* Consumption Ratio */
capture drop logmoneyratio
gen logmoneyratio = log((money1+5)/(money2+5))

capture drop cnsrdmoney
gen cnsrdmoney = 0
replace cnsrdmoney = -1 if money1 == 0
replace cnsrdmoney = 1 if money2 == 0

gen interiormoney = (cnsrdmoney ==0)
replace interiormoney = . if moneychoices != 1

egen totinteriormoney  = total(interiormoney), by(uniqid)
replace totinteriormoney = . if uniqid == .

capture drop logmoneyratiolow
gen logmoneyratiolow = logmoneyratio
replace logmoneyratiolow = . if  cnsrdmoney == -1
capture drop logmoneyratiohigh
gen logmoneyratiohigh = logmoneyratio
replace logmoneyratiohigh = . if cnsrdmoney == 1

/* Monetary Price Ratio */
capture drop logmoneypratio
gen logmoneypratio = log(discountrate)


/* Non-monotonicities in Demand for Money */
capture drop nmmoney
by id  (decisionblock discountrate), sort: gen nmmoney = (money1[_n]  - money1[_n-1]) if  money1 != .
replace nmmoney = . if choices != 2
replace nmmoney = . if discountrate < 1

capture drop nmmoneydum
gen nmmoneydum = (nmmoney > 0)
replace nmmoneydum = . if nmmoney == .

capture drop totnmmoneydum
egen totnmmoneydum = total(nmmoneydum), by(id)


/* Generate Relevant Variables for Commitment Demand Decisions */
/* Price of Commitment */
gen commitprice = date1_amt - date2_amt
gen commit = (decision ==2) if commitchoices == 1
replace commit = . if totalcommitchoices == 0
by id (commitprice), sort: gen commitdiff = commit[_n] - commit[_n+1]

/* Multiple Switching */
capture drop multiswitch
egen multiswitch = min(commitdiff), by(id)

egen totalcommit = total(commit), by(id)

/* Commit at Price 0?*/
capture drop committer
by id (commitprice), sort: gen committer = (commit[8] == 1) 
replace committer = . if totalcommitchoices == 0

/* Value of Commitment */
capture drop commitval
gen commitval = .
replace commitval = - 10 if totalcommit == 0
replace commitval = - 6 if totalcommit == 1
replace commitval = - 4 if totalcommit == 2
replace commitval = - 2 if totalcommit == 3
replace commitval = - 1 if totalcommit == 4
replace commitval = - .5 if totalcommit == 5
replace commitval = - .25 if totalcommit == 6
replace commitval =  0 if totalcommit == 7
replace commitval =  .25 if totalcommit == 8
replace commitval =  .5 if totalcommit == 9
replace commitval =  1 if totalcommit == 10
replace commitval =  2 if totalcommit == 11
replace commitval =  4 if totalcommit == 12
replace commitval =  6 if totalcommit == 13
replace commitval =  10 if totalcommit == 14

capture drop commitvallow
gen commitvallow = .
replace commitvallow = - 10 if totalcommit == 0
replace commitvallow  = - 10 if totalcommit == 1
replace commitvallow = - 6 if totalcommit == 2
replace commitvallow = - 4 if totalcommit == 3
replace commitvallow = - 2 if totalcommit == 4
replace commitvallow = - 1 if totalcommit == 5
replace commitvallow = - .5 if totalcommit == 6
replace commitvallow =  -0.25 if totalcommit == 7
replace commitvallow =  0 if totalcommit == 8
replace commitvallow =  .25 if totalcommit == 9
replace commitvallow =  0.5 if totalcommit == 10
replace commitvallow =  1 if totalcommit == 11
replace commitvallow =  2 if totalcommit == 12
replace commitvallow =  4 if totalcommit == 13
replace commitvallow =  6 if totalcommit == 14
replace commitvallow =  10 if totalcommit == 14

capture drop commitvalmid
gen commitvalmid = (commitvallow +commitval)/2
replace commitvalmid = . if multiswitch == -1



/**** Present Biased Reallocations for Work and Money */

/* Budget Shares */
capture drop bs
gen bs = date1_work/50 if date1_work != .

/* Identify Difference in Work Allocations */
/* Initial Budget Share */
capture drop initbs
by id (task pratio round), sort: gen initbs = date1_work[_n-1]/50 if  date1_work != .
replace initbs = . if round == 1
replace initbs = . if round == 4
replace initbs  = . if choices != 1

capture drop meaninitbs
capture drop temp
egen temp = mean(initbs) if round == 2, by(id)
egen meaninitbs = mean(temp),by(id)


capture drop meaninitbsfull
egen meaninitbsfull = mean(initbs), by(id)

/* Subsequent Budget Share */
capture drop subbs 
gen subbs = date1_work/50
replace subbs = . if round == 1
replace subbs = . if round == 4
replace subbs  = . if choices != 1

capture drop meansubbs
capture drop temp
egen temp = mean(subbs) if round == 2, by(id)
egen meansubbs = mean(temp),by(id)

capture drop meansubbsfull
egen meansubbsfull = mean(subbs), by(id)

/* Difference between initial and subsequent */
capture drop diff
by id (task pratio round), sort: gen diff = (date1_work  - date1_work[_n-1])/50 if  date1_work != .
replace diff = . if round == 1
replace diff = . if round == 4
replace diff = . if choices != 1

by id round task (pratio), sort: gen diffp1 = diff[1] if date1_work != .
by id  round task (pratio), sort: gen diffp2 = diff[2] if date1_work != .
by id  round task (pratio), sort: gen diffp3 = diff[3] if date1_work != .
by id  round task (pratio), sort: gen diffp4 = diff[4] if date1_work != .
by id round task (pratio), sort: gen diffp5 = diff[5] if date1_work != .


capture drop diff2
by id (task pratio round), sort: gen diff2 = (date1_work[_n+2] - date1_work[_n+1])/50 if  date1_work != .
replace diff2 = . if round == 1
replace diff2 = . if round == 4
replace diff2 = . if round == 5
replace diff2 = . if choices != 1

capture drop meandiff
egen meandiff = mean(diff), by(id round)


capture drop diffdum
gen diffdum = .
by id (task pratio round), sort: replace diffdum = 1 if date1_work - date1_work[_n-1] >0 &  date1_work != .
by id (task pratio round), sort: replace diffdum =  0 if date1_work - date1_work[_n-1] == 0 &  date1_work != .
by id (task pratio round), sort: replace diffdum =  -1 if date1_work - date1_work[_n-1] < 0 &  date1_work != .
replace diffdum = . if round == 1
replace diffdum = . if round == 4


by id round task (pratio), sort: gen diffdump1 = diffdum[1] if date1_work != .
by id  round task (pratio), sort: gen diffdump2 = diffdum[2] if date1_work != .
by id  round task (pratio), sort: gen diffdump3 = diffdum[3] if date1_work != .
by id  round task (pratio), sort: gen diffdump4 = diffdum[4] if date1_work != .
by id round task (pratio), sort: gen diffdump5 = diffdum[5] if date1_work != .



gen pb = (diffdum ==-1)
replace pb = . if date1_work == .
gen fb  = (diffdum == 1)
replace fb = . if date1_work == .
gen dc = (diffdum ==0)
replace dc = . if date1_work == .

by id round task (pratio), sort: gen pbp1 = pb[1] if date1_work != .
by id round task (pratio), sort: gen pbp2 = pb[2] if date1_work != .
by id round task (pratio), sort: gen pbp3 = pb[3] if date1_work != .
by id round task (pratio), sort: gen pbp4 = pb[4] if date1_work != .
by id round task (pratio), sort: gen pbp5 = pb[5] if date1_work != .


capture drop diffdum2
gen diffdum2 = .
by id (task pratio round), sort: replace diffdum2 = 1 if (date1_work[_n+2] - date1_work[_n+1]>0) &  date1_work != .
by id (task pratio round), sort: replace diffdum2 = 0 if (date1_work[_n+2] - date1_work[_n+1]==0) &  date1_work != .
by id (task pratio round), sort: replace diffdum2 = -1 if (date1_work[_n+2] - date1_work[_n+1]<0) &  date1_work != .
replace diffdum2 = . if round == 1
replace diffdum2 = . if round == 4
replace diffdum2 = . if round == 5

gen pb2 = (diffdum2 ==-1)
replace pb2 = . if date1_work == .
gen fb2  = (diffdum2 == 1)
replace fb2 = . if date1_work == .
gen dc2 = (diffdum2 ==0)
replace dc2 = . if date1_work == .




capture drop temp
egen temp = mean(pb) if round == 2, by(id)
egen meanpb = mean(temp), by(id)

capture drop temp
egen temp = mean(fb) if round == 2, by(id)
egen meanfb = mean(temp), by(id)

capture drop temp
egen temp = mean(dc) if round == 2, by(id)
egen meandc = mean(temp), by(id)

capture drop temp
egen temp = total(pb2), by(id)
egen countpb2 = mean(temp), by(id)

capture drop temp
egen temp = total(fb2), by(id)
egen countfb2 = mean(temp), by(id)

capture drop temp
egen temp = total(dc2), by(id)
egen countdc2 = mean(temp), by(id)

capture drop temp
egen temp = total(pb) if round ==2, by(id)
egen countpb = mean(temp), by(id)

capture drop temp
egen temp = total(fb) if round ==2, by(id)
egen countfb = mean(temp), by(id)

capture drop temp
egen temp = total(dc) if round ==2, by(id)
egen countdc = mean(temp), by(id)



capture drop temp
egen temp = mean(diff) if round ==2, by(id)
capture drop meandiff
egen meandiff = mean(temp), by(id)

capture drop temp
egen temp = mean(diff2), by(id)
egen meandiff2 = mean(temp), by(id)


capture drop temp
egen temp = mean(diff) if round ==2 & discountrate <= 1 & choices ==1, by(id)
egen meandiffplow = mean(temp), by(id)

capture drop temp
egen temp = mean(diff2) if discountrate <= 1 & choices ==1, by(id)
egen meandiff2plow = mean(temp), by(id)







/* Identify Differences in Monetary Allocations */
/* Budget Shares */
capture drop moneybs
gen moneybs = (money1)*(discountrate/20) if money1!=.


/* Subsequent Budget Share */

capture drop moneysubbs
by id pratio (decisionblock), sort: gen moneysubbs = (money1[1])*(discountrate/20) if money1!=.
replace moneysubbs = . if decisionblock ==1
replace moneysubbs = . if decisionblock ==2
capture drop temp
by id pratio (decisionblock), sort: gen temp = (money1)*(discountrate/20) if money1!=.
replace moneysubbs = temp if decisionblock == 4



/* Initial Money Budget Share */
capture drop moneyinitbs
by id pratio (decisionblock), sort: gen moneyinitbs = (money1)*(discountrate/20) if money1!=.
replace moneyinitbs = . if decisionblock ==1
replace moneyinitbs = . if decisionblock ==2
capture drop temp
by id pratio (decisionblock), sort: gen temp = (money1[3])*(discountrate/20) if money1!=.
replace moneyinitbs = temp if decisionblock == 4

capture drop meanmoneysubbs
egen meanmoneysubbs = mean(moneysubbs), by(id)

capture drop meanmoneyinitbs
egen meanmoneyinitbs = mean(moneyinitbs), by(id)


capture drop moneydiff
by id pratio (decisionblock), sort: gen moneydiff = (money1 - money1[1])*(discountrate/20) if money1!=.
replace moneydiff = . if decisionblock ==1
replace moneydiff = . if decisionblock ==2
capture drop temp
by id pratio (decisionblock), sort: gen temp = (money1[3] - money1)*(discountrate/20) if money1!=.
replace moneydiff = temp if decisionblock == 4

by id decisionblock (pratio), sort: gen moneydiffp1 = moneydiff[1] if money1!=.
by id decisionblock (pratio), sort: gen moneydiffp2 = moneydiff[2] if money1!=.
by id decisionblock (pratio), sort: gen moneydiffp3 = moneydiff[3] if money1!=.
by id decisionblock (pratio), sort: gen moneydiffp4 = moneydiff[4] if money1!=.
by id decisionblock (pratio), sort: gen moneydiffp5 = moneydiff[5] if money1!=.





capture drop moneydiffdum
gen moneydiffdum = .
replace moneydiffdum = -1 if moneydiff <0
replace moneydiffdum = 1 if moneydiff >0
replace moneydiffdum = 0 if moneydiff == 0
replace moneydiffdum = . if moneydiff == .


by id decisionblock (pratio), sort: gen moneydiffdump1 = moneydiffdum[1] if money1!=.
by id decisionblock (pratio), sort: gen moneydiffdump2 = moneydiffdum[2] if money1!=.
by id decisionblock (pratio), sort: gen moneydiffdump3 = moneydiffdum[3] if money1!=.
by id decisionblock (pratio), sort: gen moneydiffdump4 = moneydiffdum[4] if money1!=.
by id decisionblock (pratio), sort: gen moneydiffdump5 = moneydiffdum[5] if money1!=.




capture drop moneydiff2
by id pratio (decisionblock), sort: gen moneydiff2 = (money1[3] - money1[4])*(discountrate/20) if money1 != .
replace moneydiff2 = . if decisionblock ==1
replace moneydiff2 = . if decisionblock ==2
replace moneydiff2 = . if decisionblock ==4


gen pbmoney = (moneydiff < 0)
replace pbmoney = . if moneydiff == .
gen fbmoney = (moneydiff > 0)
replace fbmoney = . if moneydiff == .
gen dcmoney = (moneydiff==0)
replace dcmoney = . if moneydiff == .


by id decisionblock (pratio), sort: gen pbmoneyp1 = pbmoney[1] if money1!=.
by id decisionblock (pratio), sort: gen pbmoneyp2 = pbmoney[2] if money1!=.
by id decisionblock (pratio), sort: gen pbmoneyp3 = pbmoney[3] if money1!=.
by id decisionblock (pratio), sort: gen pbmoneyp4 = pbmoney[4] if money1!=.
by id decisionblock (pratio), sort: gen pbmoneyp5 = pbmoney[5] if money1!=.
      
 
gen pbmoney2 = (moneydiff2 < 0)
replace pbmoney2 = . if moneydiff2 == .
gen fbmoney2 = (moneydiff2 > 0)
replace fbmoney2 = . if moneydiff2 == .
gen dcmoney2 = (moneydiff2==0)
replace dcmoney2 = . if moneydiff2 == .
 
 
capture drop temp
egen temp = mean(moneydiff), by(id)
egen meanmoneydiff = mean(temp), by(id)

 

capture drop temp
egen temp = mean(moneydiff) if decisionblock == 3, by(id)
egen meanmoneydiff13 = mean(temp), by(id)


capture drop temp
egen temp = mean(moneydiff) if decisionblock == 4, by(id)
egen meanmoneydiff34 = mean(temp), by(id)

capture drop temp
egen temp = mean(pbmoney), by(id)
egen meanpbmoney = mean(temp), by(id)

capture drop temp
egen temp = mean(fbmoney), by(id)
egen meanfbmoney = mean(temp), by(id)

capture drop temp
egen temp = mean(dcmoney), by(id)
egen meandcmoney = mean(temp), by(id)



